@@ -1,5 +1,5 @@
 package CGI::Kwiki;
-$VERSION = '0.18';
+$VERSION = '0.19';
 @EXPORT = qw(attribute);
 @CHAR_CLASSES = qw($ADMIN $UPPER $LOWER $ALPHANUM $WORD $WIKIWORD);
 @EXPORT_OK = (@CHAR_CLASSES, qw(encode decode escape unescape));
@@ -79,7 +79,7 @@ sub run_cgi {
             $driver->encode($html);
             print $header, $html;
         }
-	last if $cgi_class eq 'CGI';
+        last if $cgi_class eq 'CGI';
     }
 }
 
@@ -89,8 +89,6 @@ sub handler {
     my $base_directory = $_[1] || $r->location;
     chdir($base_directory) 
       or die "Can't chdir to '$base_directory'\n";
-    eval "use Apache::Constants qw(OK REDIRECT)";
-    die $@ if $@;
 
     my $driver = load_driver();
     $CGI::Kwiki::user_name = 
@@ -101,13 +99,13 @@ sub handler {
     if (ref $html) {
         $r->method('GET');
         $r->headers_in->unset('Content-length');
-        $r->header_out('Location' => $html->{redirect});
-        $r->status(&REDIRECT || 307);
-        $r->send_http_header;
+        $r->headers_out->{'Location'} = $html->{redirect};
+        $r->status(307);
+        $r->send_http_header if $r->can('send_http_header');
     }
     else {
         $r->print($driver->cookie->header, $html);
-	$r->status(&OK || 200);
+        $r->status(200);
     }
     return;
 }
