@@ -1,36 +1,35 @@
 # $File: //depot/RT/osf/lib/RTx/Foundry.pm $ $Author: autrijus $
-# $Revision: #14 $ $Change: 9975 $ $DateTime: 2004/02/09 20:00:26 $
+# $Revision: #15 $ $Change: 10088 $ $DateTime: 2004/02/18 00:22:05 $
 
 package RTx::Foundry;
-$RTx::Foundry::VERSION = '0.00_08';
+$RTx::Foundry::VERSION = '0.00_10';
 
 1;
 
 =head1 NAME
 
-RTx::Foundry - Base classes for the OpenFoundry system
+RTx::Foundry - Base classes for the RT Foundry system
 
 =head1 VERSION
 
-This document describes version 0.08 of RTx::Foundry, released
-February 10, 2004.
+This document describes version 0.00_10 of RTx::Foundry, released July 11,
+2004.
 
 =head1 SYNOPSIS
 
 Not at the moment.  See L<http://rt.openfoundry.org/> for a demo.
 
-Currently, the only way to install OpenFoundry is from the ports files in
+Currently, the only way to install RT Foundry is from the ports files in
 L<http://rt.openfoundry.org/Foundry/Project/Download/?Queue=OpenFoundry>,
 which requires a FreeBSD system to run on.
 
 =head1 DESCRIPTION
 
-The OpenFoundry project is the code behind Taiwan's B<OSSF> initiative,
-as part of the Free Software Promotion Project initiated by the Industrial
-Development Bureau, Ministry of Economic Affairs (IDB) and executed by the
-Institute of Information Science, Academia Sinica (IIS).
+The RT Foundry project is the code behind Taiwan's B<OSSF> initiative,
+as part of the Free Software Promotion Project executed by the Institute of
+Information Science, Academia Sinica (IIS).
 
-The initial goal of OpenFoundry is to become the leading project in
+The initial goal of RT Foundry is to become the leading project in
 Taiwan to accumulate experience and knowledge of free software and open
 source code, and to establish a software program development website that
 can become a foundation platform for promoting free software. 
@@ -47,7 +46,7 @@ Chinese in due time.
 
 =head2 Overview
 
-What is OpenFoundry?
+What is RT Foundry?
 
  - Decentralized development environment
  - Modular services
@@ -66,7 +65,7 @@ Monolithic design - Why not?
  - Single point of failure
  - Difficult to integrate with existing process
 
-Neat things about OpenFoundry
+Neat things about RT Foundry
 
  - Free software under GPL / Artistic license
  - Based on mature projects
@@ -250,7 +249,7 @@ Future Plans
 
 =head1 SEE ALSO
 
-OpenFoundry Demo: L<http://rt.openfoundry.org/>
+RT Foundry Demo: L<http://rt.openfoundry.org/>
 
 OSSF Website: L<http://www.openfoundry.org/en/>
 
@@ -281,8 +280,7 @@ With collaborations from:
 
 =head1 COPYRIGHT
 
-Copyright 2003, 2004 by Industrial Development Bureau,
-Taiwan Ministry of Economic Affairs
+Copyright 2003, 2004 by Academia Sinica, Taiwan.
 
 (Except where explicitly superseded by other copyright notices)
 
